
#line 3 "fixnt.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 25
#define YY_END_OF_BUFFER 26
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[477] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   26,   25,   25,   25,    2,   25,   25,    6,
       25,   25,   24,   25,   25,   25,   25,   25,   25,   25,
       25,    9,   25,   25,   16,   25,    0,    0,    2,    0,
        0,    6,    0,    0,   24,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    9,    0,    0,   16,    0,
        0,    1,    0,    1,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   23,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    5,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   13,

        0,    0,    6,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   12,    0,    0,    0,
        0,    0,    0,    0,    0,   10,    0,    0,   12,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   15,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   24,    0,   22,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   11,    0,   17,

        0,    0,    0,    0,    8,    0,    0,    0,    3,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   14,    0,    0,    0,    0,    0,   14,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   20,    0,
        0,    0,    0,    0,    0,    4,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   19,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   21,
        0,    0,    0,    0,    0,    7,    0,    0,    0,    0,
        0,   24,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   18,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    4,    1,    1,    1,    5,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    6,    1,    7,    1,
        1,    1,    8,    1,    9,    1,   10,   11,    1,    1,
        1,    1,    1,   12,   13,   14,   15,   16,   17,   18,
       19,    1,    1,    1,    1,    1,    1,   20,   21,   22,
        1,   23,   24,   25,    1,   26,   27,    1,    1,    1,
        1,    1,    1,    1,   28,    1,   29,   30,   31,   32,

       33,   34,   35,    1,   36,    1,    1,   37,   38,   39,
       40,   41,    1,   42,   43,   44,   45,   46,    1,   47,
        1,   48,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[49] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[516] =
    {   0,
        0,    0,  809,    0,    1,    2,    6,   27,    8,   11,
       12,   13,  813,  815,  808,  809,  815,   18,  808,  815,
       29,  807,  815,   33,   35,    7,   14,   21,   23,   48,
      806,  815,   19,  805,  815,   54,  804,  803,  815,  802,
      801,  815,   49,  800,  815,   53,   40,   25,   34,   41,
       59,   60,   62,   66,  799,  815,   67,  798,  815,   71,
      797,  815,  796,  815,   73,   74,   75,   76,   81,   77,
       82,   78,   84,   85,   91,   87,   88,   89,   92,   93,
       94,   98,  102,  103,  104,  105,  106,  108,  114,  116,
      121,  125,  134,  117,  122,  126,  128,  132,  137,  141,

      795,  142,  143,  146,  151,  152,  149,  158,  153,  154,
      159,  167,  160,  161,  164,  162,  794,  815,  166,  174,
      179,  171,  180,  169,  186,  184,  190,  189,  197,  200,
      201,  793,  204,  206,  205,  207,  209,  202,  212,  217,
      214,  215,  216,  218,  219,  220,  221,  792,  815,  228,
      229,  232,  237,  233,  238,  240,  242,  244,  245,  246,
      249,  251,  255,  257,  258,  259,  262,  265,  260,  266,
      268,  281,  282,  269,  270,  284,  272,  280,  288,  291,
      292,  791,  293,  790,  301,  295,  294,  300,  302,  304,
      306,  310,  312,  315,  317,  319,  320,  321,  789,  815,

      323,  788,  769,  325,  322,  324,  326,  327,  334,  335,
      339,  344,  340,  342,  343,  345,  347,  351,  763,  366,
      785,  355,  368,  371,  373,  369,  375,  376,  784,  384,
      783,  381,  386,  762,  385,  781,  815,  389,  388,  392,
      393,  387,  397,  403,  780,  815,  391,  779,  815,  400,
      778,  755,  420,  404,  396,  406,  405,  407,  408,  409,
      776,  775,  410,  411,  774,  815,  754,  413,  430,  412,
      440,  444,  445,  447,  414,  772,  751,  770,  766,  449,
      450,  739,  453,  454,  452,  767,  766,  457,  738,  761,
      763,  460,  720,  462,  463,  467,  761,  815,  760,  815,

      464,  726,  735,  757,  815,  465,  748,  468,  815,  469,
      470,  471,  473,  724,  714,  474,  747,  479,  476,  483,
      484,  730,  724,  485,  749,  487,  490,  493,  491,  725,
      714,  494,  501,  503,  747,  505,  506,  745,  710,  744,
      712,  514,  742,  815,  515,  520,  701,  709,  739,  815,
      705,  526,  524,  531,  706,  696,  701,  530,  535,  533,
      693,  733,  695,  542,  545,  517,  689,  730,  815,  729,
      544,  548,  549,  690,  727,  815,  558,  562,  686,  534,
      546,  694,  553,  563,  724,  568,  565,  723,  719,  569,
      570,  718,  571,  573,  697,  574,  575,  679,  577,  581,

      691,  578,  579,  683,  582,  584,  681,  585,  589,  684,
      591,  586,  674,  592,  593,  713,  580,  595,  712,  815,
      596,  598,  711,  600,  710,  815,  601,  603,  609,  709,
      708,  691,  668,  668,  662,  681,  678,  700,  660,  668,
      657,  655,  658,  655,  663,  693,  692,  671,  663,  656,
      657,  665,  662,  684,  644,  652,  641,  639,  642,  639,
      647,  677,  676,  672,  671,  650,  632,  644,  636,  634,
      637,  627,  666,  665,  815,  815,  665,  664,  663,  662,
      661,  660,  659,  658,  657,  656,  655,  654,  653,  652,
      651,  650,  649,  648,  646,  645,  644,  643,  642,  641,

      640,  637,  636,  633,  631,  630,  629,  628,  627,  624,
      619,  617,  611,  603,    0
    } ;

static yyconst flex_int16_t yy_def[516] =
    {   0,
      477,  477,  477,  478,  479,  479,  480,  480,  481,  481,
      482,  482,  476,  476,  476,  483,  476,  483,  484,  476,
      484,  485,  476,  485,  485,  485,  485,  485,  485,  485,
      486,  476,  486,  487,  476,  487,  488,  483,  476,  489,
      484,  476,  484,  485,  476,  485,  485,  485,  485,  485,
      485,  485,  485,  485,  486,  476,  486,  487,  476,  487,
      488,  476,  489,  476,  484,  484,  484,  485,  485,  485,
      485,  485,  485,  485,  485,  485,  485,  486,  487,  487,
      484,  484,  484,  485,  485,  485,  485,  485,  485,  485,
      485,  485,  485,  486,  487,  487,  484,  484,  484,  485,

      490,  485,  485,  485,  485,  485,  485,  485,  485,  486,
      487,  487,  484,  484,  484,  485,  490,  476,  485,  485,
      485,  485,  485,  485,  485,  485,  486,  487,  487,  487,
      484,  491,  484,  485,  485,  485,  485,  485,  485,  485,
      485,  485,  486,  487,  487,  487,  484,  491,  476,  492,
      485,  485,  485,  485,  485,  485,  485,  485,  485,  485,
      486,  487,  487,  487,  487,  484,  492,  492,  485,  485,
      485,  485,  485,  485,  485,  485,  485,  485,  486,  487,
      487,  493,  487,  494,  492,  485,  485,  485,  485,  485,
      485,  485,  485,  485,  485,  486,  487,  487,  493,  476,

      487,  494,  476,  492,  485,  485,  485,  485,  485,  485,
      485,  485,  485,  485,  486,  487,  487,  487,  476,  492,
      495,  485,  485,  485,  485,  485,  485,  485,  496,  486,
      497,  487,  487,  476,  492,  495,  476,  485,  485,  485,
      485,  485,  485,  485,  496,  476,  486,  497,  476,  487,
      498,  476,  492,  485,  485,  485,  485,  485,  485,  485,
      499,  500,  486,  487,  498,  476,  476,  492,  485,  485,
      485,  485,  485,  485,  485,  499,  476,  500,  476,  486,
      487,  476,  492,  485,  485,  501,  502,  485,  476,  476,
      503,  487,  476,  504,  485,  485,  501,  476,  502,  476,

      485,  476,  476,  503,  476,  487,  476,  504,  476,  504,
      485,  485,  485,  476,  476,  487,  476,  504,  485,  485,
      485,  476,  476,  487,  476,  504,  485,  485,  485,  476,
      476,  487,  476,  504,  505,  485,  485,  476,  476,  506,
      476,  504,  505,  476,  485,  485,  476,  476,  506,  476,
      476,  504,  485,  485,  476,  476,  476,  504,  485,  485,
      476,  507,  476,  504,  485,  485,  476,  507,  476,  508,
      504,  485,  485,  476,  508,  476,  485,  485,  476,  485,
      485,  476,  485,  485,  509,  485,  485,  509,  476,  485,
      485,  476,  485,  485,  476,  485,  485,  476,  485,  485,

      476,  485,  485,  476,  485,  485,  476,  485,  485,  476,
      485,  485,  476,  485,  485,  510,  485,  485,  510,  476,
      485,  485,  511,  485,  511,  476,  485,  485,  485,  512,
      512,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  513,  513,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  514,  514,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  515,  515,  476,    0,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,

      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476
    } ;

static yyconst flex_int16_t yy_nxt[864] =
    {   0,
      474,   17,   20,   20,   18,   21,   21,   23,   45,   32,
       24,   25,   32,   35,   35,   45,   36,   36,   26,   39,
       56,   40,   45,   27,   45,   28,   45,   29,   23,   30,
       42,   24,   25,   43,   45,   45,   45,   46,   50,   26,
       33,   45,   45,   33,   27,   52,   28,   47,   29,   45,
       42,   53,   48,   51,   45,   59,   49,   57,   60,   54,
       45,   45,   72,   45,   71,   65,   68,   45,   56,   69,
       66,   70,   59,   67,   42,   42,   42,   45,   45,   45,
       73,   75,   45,   45,   79,   45,   45,   80,   45,   45,
       56,   94,   45,   59,   59,   42,   76,   74,   78,   42,

       77,   85,   82,   42,   45,   45,   45,   45,   84,   45,
       83,   81,   88,   89,   91,   45,   86,   45,   56,   92,
       87,  101,   45,   59,   95,   97,   45,   59,   90,   42,
       93,   96,   98,   42,  102,   45,  109,  100,   42,  106,
      104,  107,   45,   45,   45,   99,  105,   45,  108,  103,
       45,  113,   45,   45,   45,   56,  111,  112,  110,   45,
       59,   42,   42,   45,  114,   42,  120,   45,   59,  121,
       45,  132,   45,  115,  119,   45,  116,  123,  122,  124,
       45,   45,  139,  125,  129,   45,  127,   45,  141,  130,
       59,   56,  131,  135,  128,  126,  133,  138,   59,  136,

      134,   59,   42,   45,  137,   42,   45,   45,   45,  154,
       45,  155,  140,   45,  150,   45,   45,   56,   45,   59,
       59,   59,   42,  151,  142,  143,  158,  144,  152,   42,
       45,  153,  146,   45,   45,  162,  145,  156,   45,   45,
      163,   45,  168,   45,  147,   45,   45,   45,  178,  160,
       56,  176,   59,  157,  161,  159,   59,  164,   59,   59,
       42,   45,  165,   42,  170,  166,   42,   45,  169,   45,
       45,   45,  171,   45,  175,  172,  168,  177,  174,  168,
      173,   45,   45,   45,  179,   45,  193,  181,  191,   56,
      180,  195,   59,   59,   59,   45,   45,  183,  186,  184,

      182,   45,   42,   45,  185,   45,  188,   45,  187,  189,
      190,   45,  192,   45,  194,  168,   45,  212,   45,  207,
       56,   59,   59,   45,   59,   45,   42,   45,   45,  197,
      210,  196,  221,  206,  198,   45,   45,  201,  205,  168,
       45,   45,  204,   45,   56,   45,   59,  208,   59,  209,
      223,  214,   59,  211,  215,  231,   45,  220,  213,  224,
      217,   48,  226,  216,  218,   49,  225,   42,  222,   45,
       45,  230,   45,  240,   45,  241,   45,   45,  227,  228,
      168,  233,   59,  229,  242,   56,   42,   59,   45,   45,
       45,  232,   56,   45,   45,  239,  238,   45,   45,  168,

      253,   59,  235,  255,   45,   45,   45,   45,   45,   45,
       45,   56,   59,   45,   42,   45,  243,  244,  251,  254,
      247,   42,  250,  256,  258,  283,  263,  168,  260,  261,
      264,   45,  257,  259,  168,  262,  269,  270,  271,  273,
      284,   45,  268,  281,  275,   45,   45,  285,   45,  272,
       56,   59,  274,   45,   42,   45,  295,  280,   45,  288,
      292,   59,  306,  309,   45,   45,   59,  168,   45,  309,
      309,   45,   45,  286,   45,   59,  310,   45,  287,  294,
      309,  291,  310,  310,   45,   45,   59,  286,  309,  301,
      287,   45,   45,  310,   45,   59,  311,  296,  316,  312,

      321,  310,  329,  333,  309,  313,   45,   45,  318,  319,
      328,  336,  320,  324,  327,  309,   45,  310,   45,  334,
      326,   45,  354,  332,  337,   45,  359,  309,  310,  352,
      341,  309,   45,  335,   45,   45,   45,  340,  345,  342,
      310,  365,  364,  309,  310,  309,   45,   45,  358,   45,
       45,  378,  346,  372,   45,  377,  310,  373,  310,   45,
      380,  353,  360,   45,   45,  383,   45,  381,  371,   45,
       45,   45,   45,  396,   45,   45,   45,  366,   45,   45,
       45,   45,   45,   45,  408,   45,   45,   45,  386,  384,
       45,  412,   45,   45,   45,  387,   45,   45,  390,   45,

      424,   45,   45,  463,   45,  399,  391,  394,  397,  403,
       45,  447,  393,  400,  411,  421,  409,  431,  405,  425,
      415,  402,  406,  414,  419,  418,  417,  388,  375,  368,
      349,  343,  427,  308,  423,  429,  304,  299,  422,  430,
      297,  278,  276,  265,  248,  245,  236,  428,  202,  199,
      167,  148,  117,   63,   61,   58,   55,   44,   41,   38,
       34,   31,   22,   19,   16,   14,  475,  475,  473,  472,
      471,  470,  469,  468,  467,  466,  465,  464,  464,  462,
      461,  460,  459,  458,  457,  456,  455,  454,  453,  452,
      451,  450,  449,  448,  448,  446,  445,  444,  443,  442,

      441,  440,  439,  438,  437,  436,  435,  434,  433,  432,
      432,  426,  426,  420,  420,  416,  413,  410,  407,  404,
      401,  398,  395,  392,  389,  389,  385,  382,  376,  379,
      376,  369,  374,  370,  369,  367,  363,  362,  361,  357,
      350,  356,  355,  344,  351,  350,  348,  347,  344,  339,
      338,  333,  331,  330,  325,  323,  322,  317,  305,  315,
      314,  300,  298,  307,  305,  303,  302,  300,  298,  293,
      290,  279,  289,  277,  282,  266,  279,  277,  267,  266,
      249,  246,  237,  252,  249,  246,  237,  234,  219,  203,
      200,  203,  200,  149,  149,  118,  118,   64,   62,   59,

       56,   45,   42,   64,   39,   62,   59,   56,   45,   42,
       39,   37,  476,   15,   13,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476
    } ;

static yyconst flex_int16_t yy_chk[864] =
    {   0,
      515,    4,    5,    6,    4,    5,    6,    7,   26,    9,
        7,    7,   10,   11,   12,   27,   11,   12,    7,   18,
       33,   18,   28,    7,   29,    7,   48,    7,    8,    8,
       21,    8,    8,   21,   24,   49,   25,   24,   26,    8,
        9,   47,   50,   10,    8,   28,    8,   25,    8,   30,
       43,   29,   25,   27,   46,   36,   25,   33,   36,   30,
       51,   52,   49,   53,   48,   43,   46,   54,   57,   46,
       43,   47,   60,   43,   65,   66,   67,   68,   70,   72,
       50,   52,   69,   71,   60,   73,   74,   60,   76,   77,
       78,   78,   75,   79,   80,   81,   53,   51,   57,   82,

       54,   69,   66,   83,   84,   85,   86,   87,   68,   88,
       67,   65,   72,   73,   75,   89,   70,   90,   94,   76,
       71,   85,   91,   95,   79,   81,   92,   96,   74,   97,
       77,   80,   82,   98,   86,   93,   93,   84,   99,   90,
       88,   91,  100,  102,  103,   83,   89,  104,   92,   87,
      107,   97,  105,  106,  109,  110,   95,   96,   94,  108,
      111,  113,  114,  116,   98,  115,  103,  119,  112,  104,
      124,  114,  122,   99,  102,  120,  100,  106,  105,  107,
      121,  123,  123,  108,  112,  126,  110,  125,  125,  112,
      128,  127,  113,  119,  111,  109,  115,  122,  129,  120,

      116,  130,  131,  138,  121,  133,  135,  134,  136,  136,
      137,  137,  124,  139,  133,  141,  142,  143,  140,  144,
      145,  146,  147,  134,  126,  127,  140,  128,  134,  150,
      151,  135,  130,  152,  154,  144,  129,  138,  153,  155,
      144,  156,  150,  157,  131,  158,  159,  160,  160,  142,
      161,  158,  162,  139,  143,  141,  163,  145,  164,  165,
      166,  169,  146,  167,  152,  147,  168,  170,  151,  171,
      174,  175,  153,  177,  157,  154,  167,  159,  156,  168,
      155,  178,  172,  173,  161,  176,  176,  163,  174,  179,
      162,  178,  180,  181,  183,  187,  186,  165,  169,  166,

      164,  188,  185,  189,  168,  190,  171,  191,  170,  172,
      173,  192,  175,  193,  177,  185,  194,  193,  195,  188,
      196,  197,  198,  205,  201,  206,  204,  207,  208,  180,
      191,  179,  205,  187,  181,  209,  210,  183,  186,  204,
      211,  213,  185,  214,  215,  212,  216,  189,  217,  190,
      207,  195,  218,  192,  196,  216,  222,  204,  194,  208,
      198,  212,  210,  197,  201,  212,  209,  220,  206,  223,
      226,  215,  224,  224,  225,  225,  227,  228,  211,  213,
      220,  218,  232,  214,  226,  230,  235,  233,  242,  239,
      238,  217,  247,  240,  241,  223,  222,  255,  243,  235,

      235,  250,  220,  239,  244,  254,  257,  256,  258,  259,
      260,  263,  264,  270,  268,  275,  227,  228,  233,  238,
      230,  253,  232,  240,  241,  268,  247,  268,  242,  243,
      250,  269,  240,  241,  253,  244,  254,  255,  256,  258,
      269,  271,  253,  264,  260,  272,  273,  270,  274,  257,
      280,  281,  259,  285,  283,  284,  284,  263,  288,  275,
      281,  292,  292,  294,  295,  301,  306,  283,  296,  308,
      310,  311,  312,  271,  313,  316,  294,  319,  273,  283,
      318,  280,  308,  310,  320,  321,  324,  272,  326,  288,
      274,  327,  329,  318,  328,  332,  295,  285,  306,  296,

      313,  326,  321,  333,  334,  301,  336,  337,  310,  311,
      320,  328,  312,  316,  319,  342,  345,  334,  366,  326,
      318,  346,  346,  324,  329,  353,  353,  352,  342,  342,
      333,  358,  354,  327,  360,  380,  359,  332,  336,  334,
      352,  359,  358,  364,  358,  371,  365,  381,  352,  372,
      373,  373,  337,  365,  383,  372,  364,  366,  371,  377,
      377,  345,  354,  378,  384,  380,  387,  378,  364,  386,
      390,  391,  393,  393,  394,  396,  397,  360,  399,  402,
      403,  417,  400,  405,  405,  406,  408,  412,  383,  381,
      409,  409,  411,  414,  415,  384,  418,  421,  386,  422,

      422,  424,  427,  514,  428,  396,  387,  391,  394,  400,
      429,  513,  390,  397,  408,  417,  406,  512,  402,  511,
      412,  399,  403,  411,  510,  415,  414,  509,  508,  507,
      506,  505,  424,  504,  421,  428,  503,  502,  418,  429,
      501,  500,  499,  498,  497,  496,  495,  427,  494,  493,
      492,  491,  490,  489,  488,  487,  486,  485,  484,  483,
      482,  481,  480,  479,  478,  477,  474,  473,  472,  471,
      470,  469,  468,  467,  466,  465,  464,  463,  462,  461,
      460,  459,  458,  457,  456,  455,  454,  453,  452,  451,
      450,  449,  448,  447,  446,  445,  444,  443,  442,  441,

      440,  439,  438,  437,  436,  435,  434,  433,  432,  431,
      430,  425,  423,  419,  416,  413,  410,  407,  404,  401,
      398,  395,  392,  389,  388,  385,  382,  379,  375,  374,
      370,  368,  367,  363,  362,  361,  357,  356,  355,  351,
      349,  348,  347,  343,  341,  340,  339,  338,  335,  331,
      330,  325,  323,  322,  317,  315,  314,  307,  304,  303,
      302,  299,  297,  293,  291,  290,  289,  287,  286,  282,
      279,  278,  277,  276,  267,  265,  262,  261,  252,  251,
      248,  245,  236,  234,  231,  229,  221,  219,  203,  202,
      199,  184,  182,  148,  132,  117,  101,   63,   61,   58,

       55,   44,   41,   40,   38,   37,   34,   31,   22,   19,
       16,   15,   13,    3,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      476,  476,  476
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "fixnt.l"
#line 3 "fixnt.l"
  /* Time-stamp: "99/06/29 14:48:25 bauer" */

  /* Filter for Windows NT 4.0 postscript printer driver. Enables
   * the use of psnup from Angus Duggan's psutils package
   * ( http://www.dcs.ed.ac.uk/home/ajcd/psutils/ )
   * Copyright: GNU General Public License (GPL)
   * Authors:
   *         Holger Bauer 1998, 1999    bauer@itsm.uni-stuttgart.de
   *         Michael Rath 1998, 1999    rath@itsm.uni-stuttgart.de
   *         Akim Demaille      1999    demaille@inf.enst.fr
   * Version: 0.1c
   * Release Date: 1999/02/04
   *
   * Compilation:
   *
   * flex fixnt.l
   * cc -O -o fixnt lex.yy.c
   *
   * Usage:
   * csh-prompt> cat BAD_NT_Postscript_FILE.ps | fixnt | psnup -4 | gs -
   * or:
   * csh-prompt> cat BAD_NT_Postscript_FILE.ps | fixnt | psnup -4 >GOOD.ps
   *
   * Windows NT 3.5 users may be happy with:
   * csh-prompt> cat BAD_NT_Postscript_FILE.ps | \
   *             sed 's/NTPSOct94/NTPSOct95/g' | fixnt | psnup -4 >GOOD.ps
   *
   * TODO-List:
   * - check for NTPSOct94 (in the meantime use the sed command above)
   *
   *
   * BUG-Reports: to Authors (above) (please, no 20MB postscript files !!!!!!)
   * Patches (welcome) to code maintainer:   bauer@itsm.uni-stuttgart.de
   *
   */


#ifdef HAVE_CONFIG_H
# include "config.h"
# include <stdio.h>
# if defined STDC_HEADERS || defined _LIBC || defined HAVE_STDLIB_H
#  include <stdlib.h>
# endif
# if HAVE_SYS_TYPES_H
#  include <sys/types.h>
# endif
# if HAVE_UNISTD_H
#  include <unistd.h>
# endif
#else /* !HAVE_CONFIG_H */
# include <stdio.h>
# ifdef _WIN32
#  include <stdlib.h>
#  include <process.h>
#  include <wtypes.h>
#  include <winbase.h>
# else /* !_WIN32 */
#  include <unistd.h>
# endif
# include <sys/types.h>
char *getenv ();
#endif /* !HAVE_CONFIG_H */

/* Support of prototyping when possible */
#ifndef PARAMS
#  if PROTOTYPES
#    define PARAMS(protos) protos
#  else /* no PROTOTYPES */
#    define PARAMS(protos) ()
#  endif /* no PROTOTYPES */
#endif

/* Do not allow redefinition of malloc and realloc. */
#undef malloc
#undef realloc

#if defined (YYLMAX)
# undef YYLMAX
# define YYLMAX 1024
#endif

void reassemble PARAMS ((FILE*,FILE*,FILE*,char*,char*,char*));
static int first_time = 1;
FILE *font;
FILE *adobe;
FILE *body;
int ifpagesv   = 0;
int ifcorel    = 0;
int ifendsetup = 0;
int pid;
char  fontfname[255];
char adobefname[255];
char  bodyfname[255];
#ifdef _WIN32
char tmpdir[_MAX_PATH];
#else
const char *tmpdir;
#endif

#line 908 "fixnt.c"

#define INITIAL 0
#define DUMMY 1
#define NORMAL 2
#define BODY 3
#define ADOBE 4
#define FONT 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 105 "fixnt.l"



  if(first_time){
    BEGIN DUMMY;
    first_time = 0;
  }


#line 1079 "fixnt.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 477 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 815 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 114 "fixnt.l"
{ /* regular Postscript starts here ... */
      ECHO;
      BEGIN NORMAL;
}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 119 "fixnt.l"
{ /* nothing to do */
}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 122 "fixnt.l"
{ /* Corel Draw modus recognized */
  ifcorel = 1;
  ECHO;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 127 "fixnt.l"
{ /* suppress EndSetup */
  fprintf(yyout,"NTPSOct95 begin\n");
  ifendsetup = 1;
}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 132 "fixnt.l"
{ /* read up to first page and just output everyting */
  sprintf(bodyfname, "%s/fixnt_Body_%d", tmpdir, pid);
  body = fopen(bodyfname,"w+");
  fprintf(body,"%s",yytext);
  BEGIN BODY;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 139 "fixnt.l"
{    /* o.k. */
                 fprintf(yyout,"%s",yytext);
}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 143 "fixnt.l"
{ /* Adobe Stuff */
  sprintf(adobefname, "%s/fixnt_Adobe_%d", tmpdir, pid);
  adobe = fopen(adobefname,"w+");
  fprintf(adobe,"%s",yytext);
  BEGIN ADOBE;
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 150 "fixnt.l"
{ /* End of Adobe definition stuff */
  fprintf(adobe,"%s",yytext);
  BEGIN BODY;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 155 "fixnt.l"
{ /* print just everything ... */
  fprintf(adobe,"%s",yytext);
}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 160 "fixnt.l"
{ ;
  /* remove showpage definition of CorelDraw defintions */
  if( ifcorel == 1 ){
    fprintf(body," @gs @gr\n"); /* Corel draw defines spg as showpage */
  } else {
    fprintf(body,"%s",yytext);  /* Somebody else defined spg, leave it in */
  }
}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 169 "fixnt.l"
{ ;
  /* font definitions from here on  */
  sprintf(fontfname, "%s/fixnt_Font_%d", tmpdir, pid);
  font = fopen(fontfname,"w+");
  fprintf(font,"%s",yytext);
  BEGIN FONT;
}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 177 "fixnt.l"
{ /* Font definitions go to FILE* font */
  fprintf(font,"%s",yytext);
  BEGIN FONT;
}
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 182 "fixnt.l"
{ /* End of Font Definition */
  fprintf(font,"%s",yytext);
  BEGIN BODY;
}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 187 "fixnt.l"
{ ;
/* NT 3.5 Postscript Files have different FontDefinitions */
 fprintf(font,"%s",yytext);
 BEGIN FONT;
}
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 193 "fixnt.l"
{ ;
/* NT 3.5 Postscript Files have different FontDefinitions */
 fprintf(font,"%s",yytext);
 BEGIN BODY;
}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 199 "fixnt.l"
{ /* goes all to FILE *font ... */
  fprintf(font,"%s",yytext);
}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 203 "fixnt.l"
{ ;
  ifpagesv = 1;
}
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 207 "fixnt.l"
{
  fprintf(body,"%%%%Trailer\nAdobe_WinNT_Driver_Gfx dup /terminate get exec\nPageSV restore\nFontSV restore\n");
}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 211 "fixnt.l"
{ ;
  /* switch FontSV/PageSV */
  fprintf(body,"PageSV restore\nFontSV restore\n");
}
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 216 "fixnt.l"
{ ;
/* put PageSV after Trailer */
  fprintf(body,"%%%%Trailer\nPageSV restore\n");
}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 222 "fixnt.l"
{ ;
/* put PageSV/FontSV after Trailer */
  fprintf(body,"%%%%Trailer\nPageSV restore\nFontSV restore\n");
}
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 228 "fixnt.l"
{ ;
/* do not allow any PageSV's to appear within the actual body */
}
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 233 "fixnt.l"
{ ;
/* What to do at the end of the file (either recognized by %%EOF or
   reg. end of file */
 fprintf(body,"%s",yytext);
 return 0;
}
	YY_BREAK
case YY_STATE_EOF(BODY):
#line 240 "fixnt.l"
{ ;
/* This section is obsolete, could be removed ..., assume there is no
   string <<EOF>> in a Postscript file ... */

/* Only flex knows about the <<EOF>> symbol therefore put the
   reassembling process into the main program. Plain lex does return 0
   for regular end of file marks. */
 return 0;
}
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 250 "fixnt.l"
{ /* put pages in FILE *body */
  fprintf(body,"%s",yytext);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 254 "fixnt.l"
ECHO;
	YY_BREAK
#line 1402 "fixnt.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DUMMY):
case YY_STATE_EOF(NORMAL):
case YY_STATE_EOF(ADOBE):
case YY_STATE_EOF(FONT):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 477 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 477 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 476);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 254 "fixnt.l"


int
yywrap ()
{
  return 1;
}

int
main ()
{
#ifdef _WIN32
  GetTempPath(_MAX_PATH, tmpdir);
#else
  if (!(tmpdir = getenv("TMPDIR")))
    tmpdir = "/tmp";
#endif
  pid = (int) getpid ();
  yylex();
  /* at the end always reassemble the file and clean up ... */
  reassemble(adobe, font, body, adobefname, fontfname, bodyfname);

  return 0;
}

void
reassemble (adobe, font, body, adobefname, fontfname, bodyfname)
  FILE* adobe;
  FILE* font;
  FILE* body;
  char *adobefname;
  char *fontfname;
  char *bodyfname;
{
  int xx;

  /* put everything in right order ... */
  if( adobe != NULL ){
    rewind(adobe);
    while( (xx = getc( adobe )) != EOF ){
      putc(xx,yyout);
    }
    fclose(adobe);
    remove(adobefname);
  }

  if( font != NULL){
    rewind(font);
    while( (xx = getc( font )) != EOF ){
      putc(xx,yyout);
    }
    fclose(font);
    remove(fontfname);
  }

  if( ifendsetup == 1){
    fprintf(yyout,"%%%%EndSetup:\n");
  }

  if( body != NULL){
    rewind(body);
    if(ifpagesv == 1)
      fprintf(yyout,"NTPSOct95 /PageSV save put\n");
    while( (xx = getc( body )) != EOF ){
      putc(xx,yyout);
    }
    fclose(body);
    remove(bodyfname);
  }
  return;
}

/*
  Local Variables:
  Mode: C
  End:
*/

